pub enum Flags {
Extended,
Remote,
SingleShot,
SelfReception,
DlcNonComp,
None,
}Expand description
Twai message flags
Variants
Extended
Message is in Extended Frame Format (29bit ID)
Remote
Message is a Remote Frame (Remote Transmission Request)
SingleShot
Transmit message using Single Shot Transmission (Message will not be retransmitted upon error or loss of arbitration). Unused for received message.
SelfReception
Transmit message using Self Reception Request (Transmitted message will also received by the same node). Unused for received message.
DlcNonComp
Message’s Data length code is larger than 8. This will break compliance with TWAI
None