Struct CanDriver
Source pub struct CanDriver<'d>();
Associated frame type.
Associated error type.
Puts a frame in the transmit buffer. Blocks until space is available in
the transmit buffer.
Blocks until a frame was received or an error occured.
Associated frame type.
Associated error type.
Puts a frame in the transmit buffer. Blocks until space is available in
the transmit buffer.
Blocks until a frame was received or an error occured.
Associated frame type.
Associated error type.
Puts a frame in the transmit buffer to be sent on the bus.
Read more
Returns a received frame if available.
Associated frame type.
Associated error type.
Puts a frame in the transmit buffer to be sent on the bus.
Read more
Returns a received frame if available.
Executes the destructor for this type.
Read more
🔬This is a nightly-only experimental API. (pin_ergonomics)
Execute the destructor for this type, but different to
Drop::drop, it requires
self
to be pinned.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.